@@ -22,7 +22,7 @@ use Travel::Status::DE::HAFAS::Journey;
 use Travel::Status::DE::HAFAS::StopFinder;
 use Travel::Status::DE::HAFAS::Stop;
 
-our $VERSION = '4.12';
+our $VERSION = '4.13';
 
 # {{{ Endpoint Definition
 
@@ -442,7 +442,7 @@ sub new_p {
 				$self->parse_board;
 			}
 			if ( $self->errstr ) {
-				$promise->reject( $self->errstr );
+				$promise->reject( $self->errstr, $self );
 			}
 			else {
 				$promise->resolve($self);
@@ -903,7 +903,7 @@ monitors
 
 =head1 VERSION
 
-version 4.12
+version 4.13
 
 =head1 DESCRIPTION
 
@@ -1016,9 +1016,12 @@ Request a polyline (series of geo-coordinates) indicating the train's route.
 =item my $status_p = Travel::Status::DE::HAFAS->new_p(I<%opt>)
 
 Return a promise that resolves into a Travel::Status::DE::HAFAS instance
-($status) on success and rejects with an error message ($status->errstr) on
-failure. In addition to the arguments of B<new>, the following mandatory
-arguments must be set.
+($status) on success and rejects with an error message on failure. If the
+failure occured after receiving a response from the HAFAS backend, the rejected
+promise contains a Travel::Status::DE::HAFAS instance as a second argument.
+This instance can be used e.g. to call similar_stops in case of an ambiguous
+location specifier. In addition to the arguments of B<new>, the following
+mandatory arguments must be set.
 
 =over
 
@@ -1146,7 +1149,7 @@ Travel::Status::DE::HAFAS::Journey(3pm), Travel::Status::DE::HAFAS::StopFinder(3
 
 =head1 AUTHOR
 
-Copyright (C) 2015-2022 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2015-2022 by Birte Kristina Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
